@@ -31,9 +31,9 @@ except ImportError:
     warn_once("Note: Failed to import the optional openff.evaluator package. ")
 
 try:
-    from openforcefield.typing.engines import smirnoff
+    from openff.toolkit.typing.engines import smirnoff
 except ImportError:
-    warn_once("Note: Failed to import the optional openforcefield package. ")
+    warn_once("Note: Failed to import the optional openff-toolkit package. ")
 
 logger = getLogger(__name__)
 
